from nccompare import compare
from nccompare.conf import settings


def get_args(raw_args=None):
    import argparse

    parse = argparse.ArgumentParser(description="netCDF Comparison Tool")
    # General args
    parse.add_argument('folder1', type=str, help="Path of first folder to compare")
    parse.add_argument('folder2', type=str, help="Path of second folder to compare")
    parse.add_argument('--name', type=str, default=settings.DEFAULT_NAME_TO_COMPARE,
                       help="Name of the files to compare."
                            "It can be a sub-set of the complete name or a regex expression")
    parse.add_argument('--maxdepth', type=int, default=settings.DEFAULT_MAXDEPTH,
                       help="Descend at most levels levels of directories below the "
                            "starting-points. If set to -1 it scan all the subdirectories")
    parse.add_argument('--common_pattern', type=str, default=None,
                       help="Common file pattern in two files to compare. "
                            "Es mfsX_date.nc and expX_date.nc -> date.nc is the common part")
    parse.add_argument('--variables', nargs='+', default=None, help="Variable to compare")
    parse.add_argument('-v', dest="verbose_level", default=3, type=int,
                       help="Verbose level from 1 (CRITICAL) to 5 (logger.debug). Default is 2 (ERROR)")
    parse.add_argument('--last_time_step', dest='last_time_step', action='store_true', default=False,
                       help='If True, compare only the last time step available in each file')

    return parse.parse_args(raw_args)


def main():
    compare.main(get_args())


if __name__ == '__main__':
    main()
